==> 1.1.2.1.tar.gz: waifu2x-caffe/waifu2x-caffe-gui/resource.h <==
/ / { { N O _ D E P E N D E N C I E S } } 
 
 / /   M i c r o s o f t   V i s u a l   C + +   g0ubU00_0000000  00000
 
 / /   R e s o u r c e . r c   g0O(u
 
 / / 
 
 # d e f i n e   I D D _ D I A L O G                                             1 0 1 
 
 # d e f i n e   I D C _ E D I T _ I N P U T                                     1 0 0 1 
 
 # d e f i n e   I D C _ E D I T _ O U T P U T                                   1 0 0 2 
 
 # d e f i n e   I D C _ R A D I O _ M O D E _ C P U                             1 0 0 3 
 
 # d e f i n e   I D C _ R A D I O _ M O D E _ G P U                             1 0 0 4 
 
 # d e f i n e   I D C _ R A D I O _ M O D E _ N O I S E                         1 0 0 5 
 
 # d e f i n e   I D C _ R A D I O _ M O D E _ S C A L E                         1 0 0 6 
 
 # d e f i n e   I D C _ R A D I O _ M O D E _ N O I S E _ S C A L E             1 0 0 7 
 
 # d e f i n e   I D C _ R A D I O _ A U T O _ S C A L E                         1 0 0 8 
 
 # d e f i n e   I D C _ R A D I O N O I S E _ L E V E L 1                       1 0 1 0 
 
 # d e f i n e   I D C _ R A D I O N O I S E _ L E V E L 2                       1 0 1 1 
 
 # d e f i n e   I D C _ E D I T _ S C A L E _ R A T I O                         1 0 1 2 
 
 # d e f i n e   I D C _ B U T T O N _ E X E C                                   1 0 1 3 
 
 # d e f i n e   I D C _ E D I T _ S C A L E _ W I D T H                         1 0 1 4 
 
 # d e f i n e   I D C _ P R O G R E S S                                         1 0 1 5 
 
 # d e f i n e   I D C _ B U T T O N _ C A N C E L                               1 0 1 6 
 
 # d e f i n e   I D C _ B U T T O N _ C H E C K _ C U D N N                     1 0 1 7 
 
 # d e f i n e   I D C _ E D I T 1                                               1 0 1 8 
 
 # d e f i n e   I D C _ E D I T _ I N P U T _ E X T _ L I S T                   1 0 1 8 
 
 # d e f i n e   I D C _ E D I T 2                                               1 0 1 9 
 
 # d e f i n e   I D C _ E D I T _ L O G                                         1 0 1 9 
 
 # d e f i n e   I D C _ E D I T 3                                               1 0 2 0 
 
 # d e f i n e   I D C _ E D I T _ O U T _ Q U A L I T Y                         1 0 2 0 
 
 # d e f i n e   I D C _ E D I T _ S C A L E _ W I D T H 2                       1 0 2 1 
 
 # d e f i n e   I D C _ E D I T _ S C A L E _ H E I G H T                       1 0 2 1 
 
 # d e f i n e   I D C _ C O M B O 2                                             1 0 2 2 
 
 # d e f i n e   I D C _ C O M B O _ C R O P _ S I Z E                           1 0 2 2 
 
 # d e f i n e   I D C _ R A D I O _ M O D E L _ Y                               1 0 2 3 
 
 # d e f i n e   I D C _ R A D I O _ M O D E L _ R G B                           1 0 2 4 
 
 # d e f i n e   I D C _ R A D I O 3                                             1 0 2 5 
 
 # d e f i n e   I D C _ R A D I O _ M O D E L _ P H O T O                       1 0 2 5 
 
 # d e f i n e   I D C _ C H E C K 1                                             1 0 2 6 
 
 # d e f i n e   I D C _ C H E C K _ T T A                                       1 0 2 6 
 
 # d e f i n e   I D C _ B U T T O N _ I N P U T _ R E F                         1 0 2 7 
 
 # d e f i n e   I D C _ C O M B O _ C R O P _ S I Z E 2                         1 0 2 8 
 
 # d e f i n e   I D C _ C O M B O _ L A N G                                     1 0 2 8 
 
 # d e f i n e   I D C _ S T A T I C _ I O _ S E T T I N G                       1 0 2 9 
 
 # d e f i n e   I D C _ S T A T I C _ I N P U T _ P A T H                       1 0 3 0 
 
 # d e f i n e   I D C _ S T A T I C _ O U T P U T _ P A T H                     1 0 3 1 
 
 # d e f i n e   I D C _ S T A T I C _ T A N S _ E X T _ L I S T                 1 0 3 2 
 
 # d e f i n e   I D C _ S T A T I C _ O U T P U T _ E X T                       1 0 3 3 
 
 # d e f i n e   I D C _ S T A T I C _ O U T P U T _ Q U A L I T Y               1 0 3 4 
 
 # d e f i n e   I D C _ S T A T I C _ Q U A L I T Y _ P R O C E S S _ S E T T I N G   1 0 3 5 
 
 # d e f i n e   I D C _ S T A T I C _ T R A N S _ M O D E                       1 0 3 6 
 
 # d e f i n e   I D C _ S T A T I C _ J P E G _ N O I S E _ L E V E L           1 0 3 7 
 
 # d e f i n e   I D C _ S T A T I C _ S C A L E _ R A T E                       1 0 3 8 
 
 # d e f i n e   I D C _ S T A T I C _ M O D E L                                 1 0 3 9 
 
 # d e f i n e   I D C _ S T A T I C _ P R O C E S S _ S P E E D _ S E T T I N G   1 0 4 0 
 
 # d e f i n e   I D C _ S T A T I C _ P R O C E S S O R                         1 0 4 1 
 
 # d e f i n e   I D C _ S T A T I C _ C R O P _ S I Z E                         1 0 4 2 
 
 # d e f i n e   I D C _ S T A T I C _ L A N G _ U I                             1 0 4 3 
 
 # d e f i n e   I D C _ S T A T I C _ O U T P U T _ D E P T H                   1 0 4 4 
 
 # d e f i n e   I D C _ C O M B O _ O U T P U T _ D E P T H                     1 0 4 5 
 
 # d e f i n e   I D C _ C O M B O 1                                             1 0 4 6 
 
 # d e f i n e   I D C _ C O M B O _ O U T _ E X T                               1 0 4 6 
 
 # d e f i n e   I D C _ R A D I O _ S C A L E _ R A T I O                       1 0 4 7 
 
 # d e f i n e   I D C _ R A D I O _ S C A L E _ W I D T H                       1 0 4 8 
 
 # d e f i n e   I D C _ R A D I O _ S C A L E _ H E I G H T                     1 0 4 9 
 
 # d e f i n e   I D C _ R A D I O _ A U T O _ S T A R T _ N O N E               1 0 5 0 
 
 # d e f i n e   I D C _ R A D I O _ A U T O _ S T A R T _ O N E                 1 0 5 1 
 
 # d e f i n e   I D C _ R A D I O _ A U T O _ S T A R T _ M U L T I             1 0 5 2 
 
 # d e f i n e   I D C _ S T A T I C _ A U T O _ S T A R T                       1 0 5 3 
 
 
 
 / /   N e x t   d e f a u l t   v a l u e s   f o r   n e w   o b j e c t s 
 
 / /   
 
 # i f d e f   A P S T U D I O _ I N V O K E D 
 
 # i f n d e f   A P S T U D I O _ R E A D O N L Y _ S Y M B O L S 
 
 # d e f i n e   _ A P S _ N E X T _ R E S O U R C E _ V A L U E                 1 0 3 
 
 # d e f i n e   _ A P S _ N E X T _ C O M M A N D _ V A L U E                   4 0 0 0 1 
 
 # d e f i n e   _ A P S _ N E X T _ C O N T R O L _ V A L U E                   1 0 5 4 
 
 # d e f i n e   _ A P S _ N E X T _ S Y M E D _ V A L U E                       1 0 1 
 
 # e n d i f 
 
 # e n d i f 
 
 

==> 1.6.0.1.tar.gz: waifu2x-caffe/waifu2x-caffe-gui/resource.h <==
/ / { { N O _ D E P E N D E N C I E S } } 
 
 / /   M i c r o s o f t   V i s u a l   C + +   g0ubU00_0000000  00000
 
 / /   R e s o u r c e . r c   g0O(u
 
 / / 
 
 # d e f i n e   I D D _ D I A L O G                                             1 0 1 
 
 # d e f i n e   I D C _ E D I T _ I N P U T                                     1 0 0 1 
 
 # d e f i n e   I D C _ E D I T _ O U T P U T                                   1 0 0 2 
 
 # d e f i n e   I D C _ R A D I O _ M O D E _ C P U                             1 0 0 3 
 
 # d e f i n e   I D C _ R A D I O _ M O D E _ G P U                             1 0 0 4 
 
 # d e f i n e   I D C _ R A D I O _ M O D E _ N O I S E                         1 0 0 5 
 
 # d e f i n e   I D C _ R A D I O _ M O D E _ S C A L E                         1 0 0 6 
 
 # d e f i n e   I D C _ R A D I O _ M O D E _ N O I S E _ S C A L E             1 0 0 7 
 
 # d e f i n e   I D C _ R A D I O _ A U T O _ S C A L E                         1 0 0 8 
 
 # d e f i n e   I D C _ R A D I O N O I S E _ L E V E L 1                       1 0 1 0 
 
 # d e f i n e   I D C _ R A D I O N O I S E _ L E V E L 2                       1 0 1 1 
 
 # d e f i n e   I D C _ E D I T _ S C A L E _ R A T I O                         1 0 1 2 
 
 # d e f i n e   I D C _ B U T T O N _ E X E C                                   1 0 1 3 
 
 # d e f i n e   I D C _ E D I T _ O U T _ E X T                                 1 0 1 4 
 
 # d e f i n e   I D C _ P R O G R E S S                                         1 0 1 5 
 
 # d e f i n e   I D C _ B U T T O N _ C A N C E L                               1 0 1 6 
 
 # d e f i n e   I D C _ B U T T O N _ C H E C K _ C U D N N                     1 0 1 7 
 
 # d e f i n e   I D C _ E D I T 1                                               1 0 1 8 
 
 # d e f i n e   I D C _ E D I T _ I N P U T _ E X T _ L I S T                   1 0 1 8 
 
 # d e f i n e   I D C _ E D I T 2                                               1 0 1 9 
 
 # d e f i n e   I D C _ E D I T _ L O G                                         1 0 1 9 
 
 # d e f i n e   I D C _ E D I T 3                                               1 0 2 0 
 
 # d e f i n e   I D C _ C O M B O 2                                             1 0 2 2 
 
 # d e f i n e   I D C _ C O M B O _ C R O P _ S I Z E                           1 0 2 2 
 
 # d e f i n e   I D C _ R A D I O _ M O D E L _ Y                               1 0 2 3 
 
 # d e f i n e   I D C _ R A D I O _ M O D E L _ R G B                           1 0 2 4 
 
 # d e f i n e   I D C _ R A D I O 3                                             1 0 2 5 
 
 # d e f i n e   I D C _ R A D I O _ M O D E L _ P H O T O                       1 0 2 5 
 
 
 
 / /   N e x t   d e f a u l t   v a l u e s   f o r   n e w   o b j e c t s 
 
 / /   
 
 # i f d e f   A P S T U D I O _ I N V O K E D 
 
 # i f n d e f   A P S T U D I O _ R E A D O N L Y _ S Y M B O L S 
 
 # d e f i n e   _ A P S _ N E X T _ R E S O U R C E _ V A L U E                 1 0 2 
 
 # d e f i n e   _ A P S _ N E X T _ C O M M A N D _ V A L U E                   4 0 0 0 1 
 
 # d e f i n e   _ A P S _ N E X T _ C O N T R O L _ V A L U E                   1 0 2 6 
 
 # d e f i n e   _ A P S _ N E X T _ S Y M E D _ V A L U E                       1 0 1 
 
 # e n d i f 
 
 # e n d i f 
 
 
